def get_analyis_type() -> str:
    """Get the analysis type.

    Args:
        None

    Returns:
        str: the analysis type

    Raises:
        None
    """
    analysis_type = None
    while analysis_type is None or analysis_type == "":
        analysis_type = input("What is the analysis type? : ")
    return analysis_type.strip()


def get_batch_id() -> str:
    """Get the batch ID type.

    Args:
        None

    Returns:
        str: the batch ID

    Raises:
        None
    """
    batch_id = None
    while batch_id is None or batch_id == "":
        batch_id = input("What is the batch ID? : ")
    return batch_id.strip()




import hashlib
import logging
import os
import platform
import sys
import string

from typing import Optional
from rich.console import Console
from datetime import datetime

error_console = Console(stderr=True, style="bold red")


def calculate_md5(file_path: str) -> str:
    """Calculate the md5 checksum for the specified file.

    Args:
        file_path (str): the file for which the md5 checksum will be calculated

    Returns:
        str: the calculated md5 checksum
    """
    md5_hash = hashlib.md5()
    logging.info(f"Will attempt to calculate the MD5 checksum for file '{file_path}'")

    with open(file_path, "rb") as file:
        # Read the file in chunks to efficiently handle large files
        for chunk in iter(lambda: file.read(4096), b""):
            md5_hash.update(chunk)

    return md5_hash.hexdigest()


def get_file_creation_date(file_path: str) -> datetime:
    """Determine the creation date for the specified file.

    Args:
        file_path (str): the absolute path of the file

    Returns:
        datetime: the date the file was created according to the operating system
    """
    if platform.system() == "Windows":
        # On Windows, use creation time
        creation_time = os.path.getctime(file_path)
    else:
        # On Unix-based systems, use birth time (creation time)
        # Note: Not all file systems support birth time, and it might not be available on some systems.
        stat_info = os.stat(file_path)
        creation_time = stat_info.st_mtime

    # Convert the timestamp to a readable date
    creation_date = datetime.fromtimestamp(creation_time)

    return creation_date


def check_infile_status(infile: str, extension: Optional[str] = None) -> None:
    """Check if the file exists, if it is a regular file and whether it has
    content.

    Args:
        infile (str): the file to be checked

    Raises:
        None
    """

    error_ctr = 0

    if infile is None or infile == "":
        error_console.print(f"'{infile}' is not defined")
        error_ctr += 1
    else:
        if not os.path.exists(infile):
            error_ctr += 1
            error_console.print(f"'{infile}' does not exist")
        else:
            if not os.path.isfile(infile):
                error_ctr += 1
                error_console.print(f"'{infile}' is not a regular file")
            if os.stat(infile).st_size == 0:
                error_console.print(f"'{infile}' has no content")
                error_ctr += 1
            if extension is not None and not infile.endswith(extension):
                error_console.print(
                    f"'{infile}' does not have filename extension '{extension}'"
                )
                error_ctr += 1

    if error_ctr > 0:
        error_console.print(f"Detected problems with input file '{infile}'")
        sys.exit(1)


def check_indir_status(indir: str = None) -> None:
    """Check if the directory exists and is a regular directory.

    Args:
        indir (str): the directory to be checked
    """
    error_ctr = 0

    if indir is None or indir == '':
        error_console.print(f"'{indir}' is not defined")
        error_ctr += 1
    else:
        if not os.path.exists(indir):
            error_ctr += 1
            error_console.print(f"directory '{indir}' does not exist")
        else:
            if not os.path.isdir(indir):
                error_ctr += 1
                error_console.print(f"'{indir}' is not a regular directory")

    if error_ctr > 0:
        error_console.print(f"Detected problems with input directory '{indir}'")
        sys.exit(1)


def get_file_size(file_path: str) -> int:
    # Check if the file exists
    if os.path.exists(file_path):
        # Get the file size in bytes
        file_size = os.path.getsize(file_path)
        return file_size
    else:
        raise Exception(f"The file '{file_path}' does not exist.")


def get_line_count(file_path: str) -> int:
    # if is_binary_file(file_path):
    #     print(f"Unable to get line count for binary file '{file_path}'")
    #     return None
    try:
        with open(file_path, 'r') as file:
            line_count = sum(1 for line in file)
        return line_count
    except FileNotFoundError:
        print(f"File '{file_path}' not found.")
        return None
    except Exception as e:
        print(f"An error occurred: {e}")
        return None


def is_binary_file(file_path: str, block_size: int = 1024) -> bool:
    try:
        with open(file_path, 'rb') as file:
            block = file.read(block_size)
            if not block:  # Empty file
                return False

            # Check for the presence of null bytes (indicative of binary files)
            if b'\x00' in block:
                return True

            # Check for a significant number of non-printable ASCII characters
            text_characters = set(string.printable)
            if not all(byte in text_characters or byte == b'\n' for byte in block):
                return True

            return False  # File is likely text

    except FileNotFoundError:
        print(f"File '{file_path}' not found.")
        return None
    except Exception as e:
        print(f"An error occurred: {e}")
        return None

def get_file_list_from_directory(indir: str = None, extension: str = None) -> list:
    """Get the list of files in the specified directory
    :param indir: {str} - the directory to search for files
    :param extension: {str} - the file extension to filter on
    :returns file_list: {list} - the list of files found in the directory
    """
    if extension is None:
        logging.info(f"Going to search for files in directory '{indir}'")
    else:
        logging.info(f"Going to search for files with extension '{extension}' in directory '{indir}'")

    file_list = []
    for dirpath, dirnames, filenames in os.walk(indir):
        if 'venv' in dirpath:
            logging.info(f"Going to ignore files in directory '{dirpath}'")
            continue
        for name in filenames:
            file_path = os.path.normpath(os.path.join(dirpath, name))
            if os.path.isfile(file_path):
                if extension is not None:
                    if file_path.endswith(f'.{extension}'):
                        file_list.append(file_path)
                else:
                    file_list.append(file_path)

    return file_list




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
import sys
import click
import pathlib
import logging
import pathlib

from rich.console import Console
from datetime import datetime
from typing import List

DEFAULT_PROJECT = "bg-helper-utils"

EXECUTABLES = [
    "find-batch-analysis-dir",
    "find-samplesheet",
]

DEFAULT_ALIAS_PREFIX = "jj"

DEFAULT_TIMESTAMP = str(datetime.today().strftime("%Y-%m-%d-%H%M%S"))

DEFAULT_OUTDIR = os.path.join(
    "/tmp/",
    os.getenv("USER"),
    DEFAULT_PROJECT,
    os.path.basename(__file__),
    DEFAULT_TIMESTAMP,
)

LOGGING_FORMAT = "%(levelname)s : %(asctime)s : %(pathname)s : %(lineno)d : %(message)s"

LOG_LEVEL = logging.INFO

DEFAULT_VERBOSE = True


error_console = Console(stderr=True, style="bold red")

console = Console()


def create_aliases_file(wrapper_scripts: List[str], outdir: str, prefix: str = DEFAULT_ALIAS_PREFIX) -> None:
    """Create a file with aliases for the wrapper scripts.

    Args:
        wrapper_scripts (List[str]): list of wrapper scripts
        outdir (str): output directory
    """
    outfile = os.path.join(outdir, f"{DEFAULT_PROJECT}-aliases.txt")

    with open(outfile, 'w') as of:
        of.write(f"## method-created: {os.path.abspath(__file__)}\n")
        of.write(f"## date-created: {str(datetime.today().strftime('%Y-%m-%d-%H%M%S'))}\n")
        of.write(f"## created-by: {os.environ.get('USER')}\n")
        for wrapper_script in wrapper_scripts:
            alias = os.path.basename(wrapper_script).replace(".sh", "")
            line = f"alias {prefix}-{alias}='bash {wrapper_script}'"
            of.write(f"{line}\n")

    logging.info(f"Wrote file '{outfile}'")
    print(f"Wrote file '{outfile}'")


def create_wrapper_script(infile: str, outdir: str) -> str:

    outfile = None
    if not infile.endswith(".sh"):
        outfile = os.path.join(outdir, os.path.basename(infile) + ".sh")

    with open(outfile, "w") as of:
        of.write("#!/bin/bash\n")
        # of.write(
        #     'SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"\n'
        # )

        bin_dir = os.path.dirname(__file__)
        activate_script = os.path.join(bin_dir, "activate")
        of.write(f"source {activate_script}\n")

        of.write(f"python {bin_dir}/{os.path.basename(infile)} \"$@\"")

    logging.info(f"Wrote wrapper shell script '{outfile}'")
    return outfile



@click.command()
@click.option(
    "--outdir",
    type=str,
    help=f"Optional: The default is the current working directory - default is '{DEFAULT_OUTDIR}'",
)
@click.option(
    "--alias-prefix",
    type=str,
    help=f"Optional: The prefix to be applied to the aliases - default is '{DEFAULT_ALIAS_PREFIX}'",
)
def main(outdir: str, alias_prefix: str):
    """Create wrapper shell scripts and aliases."""
    error_ctr = 0

    if error_ctr > 0:
        click.echo(click.get_current_context().get_help())
        sys.exit(1)

    if outdir is None:
        outdir = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
        console.print(f"[bold yellow]--outdir was not specified and therefore was set to '{outdir}'[/]")

    if not os.path.exists(outdir):
        pathlib.Path(outdir).mkdir(parents=True, exist_ok=True)
        console.print(f"[bold yellow]Created output directory '{outdir}'[/]")

    if alias_prefix is None:
        alias_prefix = DEFAULT_ALIAS_PREFIX
        console.print(f"[bold yellow]--alias-prefix was not specified and therefore was set to '{alias_prefix}'[/]")

    wrapper_scripts = []

    for executable in EXECUTABLES:
        console_script = os.path.join(os.path.dirname(__file__), executable)
        if not os.path.exists(console_script):
            raise Exception(f"Console script '{console_script}' does not exist")
        wrapper_script = create_wrapper_script(console_script, outdir)
        wrapper_scripts.append(wrapper_script)

    create_aliases_file(wrapper_scripts, outdir, alias_prefix)

    console.print(f"[bold green]Execution of {os.path.abspath(__file__)} completed[/]")


if __name__ == "__main__":
    main()



from rich.progress import Progress
from typing import Any, Callable, List

def show_progress_bar(
    func: Callable[[str], None],
    desc: str,
    advance: int = 1,
    items: List[Any] = None
    ) -> None:
    """Display a progress bar to show progress of a function.

    Args:
        func (Callable[[str], None]): The function to be called.
        desc (str): The description of the progress bar.
        advance (int, optional): The number of increments to advance the progress bar by. Defaults to 1.
        items (List[Any], optional): The list of items to be processed. Defaults to None.
    """
    with Progress() as progress:
        task = progress.add_task(f"[cyan]{desc}", total=len(items))

        for item in items:
            # Simulate processing the file (replace this with your actual processing logic)
            func(item)

            # Update the progress bar
            progress.update(task, advance=advance)




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
import sys
import click
import pathlib
import logging
import pathlib
import yaml

from rich.console import Console
from datetime import datetime
from typing import Any, Dict

from .console_helper import print_red, print_yellow, print_green
from .file_utils import check_indir_status, check_infile_status, calculate_md5, get_file_size, get_file_creation_date, get_line_count
from .helper import get_analyis_type, get_batch_id

DEFAULT_PROJECT = "bg-helper-utils"

DEFAULT_TIMESTAMP = str(datetime.today().strftime("%Y-%m-%d-%H%M%S"))

DEFAULT_OUTDIR = os.path.join(
    "/tmp/",
    os.getenv("USER"),
    DEFAULT_PROJECT,
    os.path.basename(__file__),
    DEFAULT_TIMESTAMP,
)


DEFAULT_CONFIG_FILE = os.path.join(
    os.getcwd(),
    'conf',
    'config.yaml'
)

DEFAULT_LOGGING_FORMAT = "%(levelname)s : %(asctime)s : %(pathname)s : %(lineno)d : %(message)s"

DEFAULT_LOGGING_LEVEL = logging.INFO

DEFAULT_VERBOSE = False


error_console = Console(stderr=True, style="bold red")

console = Console()


def find_samplesheet(config_file: str, config: Dict[str, Any]) -> None:
    """Find the samplesheet.

    Args:
        config_file (str): the configuration file path
        config (Dict[str, Any]): The configuration
    """
    if "base_samplesheet_dir" not in config:
        raise Exception(f"Could not find 'base_samplesheet_dir' in config file '{config_file}'")

    base_samplesheet_dir = config["base_samplesheet_dir"]
    check_indir_status(base_samplesheet_dir)

    analysis_type = get_analyis_type()
    batch_id = get_batch_id()

    if "samplesheet" not in config:
        raise Exception(f"Could not find 'samplesheet' in config file '{config_file}'")

    if "analysis_file_type_mapping" not in config["samplesheet"]:
        raise Exception(f"Could not find 'analysis_file_type_mapping' in 'samplesheet' section in config file '{config_file}'")

    if analysis_type not in config["samplesheet"]["analysis_file_type_mapping"]:
        raise Exception(f"Could not find '{analysis_type}' in 'analysis_file_type_mapping' in 'samplesheet' section in config file '{config_file}'")

    analysis_file_type = config["samplesheet"]["analysis_file_type_mapping"][analysis_type]

    samplesheet = os.path.join(
        base_samplesheet_dir,
        batch_id,
        f"{batch_id}_{analysis_file_type}_samplesheet.csv"
    )

    if os.path.exists(samplesheet):

        console.print(f"\n[bold green]Found samplesheet[/] '{samplesheet}'")
        md5sum = calculate_md5(samplesheet)
        filesize = get_file_size(samplesheet)
        date_created = get_file_creation_date(samplesheet)
        line_count = get_line_count(samplesheet)

        console.print(f"[yellow]md5sum[/]: {md5sum}")
        console.print(f"[yellow]filesize[/]: {filesize}")
        console.print(f"[yellow]date_created[/]: {date_created}")
        console.print(f"[yellow]line_count[/]: {line_count}")
    else:
        print_red(f"Could not find samplesheet '{samplesheet}'")



def validate_verbose(ctx, param, value):
    if value is None:
        click.secho("--verbose was not specified and therefore was set to 'True'", fg='yellow')
        return DEFAULT_VERBOSE
    return value


@click.command()
@click.option('--config_file', type=click.Path(exists=True), help=f"The configuration file for this project - default is '{DEFAULT_CONFIG_FILE}'")
@click.option('--logfile', help="The log file")
@click.option('--outdir', help="The default is the current working directory - default is '{DEFAULT_OUTDIR}'")
@click.option('--outfile', help="The output final report file")
@click.option('--verbose', is_flag=True, help=f"Will print more info to STDOUT - default is '{DEFAULT_VERBOSE}'.", callback=validate_verbose)
def main(config_file: str, logfile: str, outdir: str, outfile: str, verbose: bool):
    """Find the samplesheet."""
    error_ctr = 0

    if error_ctr > 0:
        click.echo(click.get_current_context().get_help())
        sys.exit(1)

    if config_file is None:
        config_file = DEFAULT_CONFIG_FILE
        print_yellow(f"--config_file was not specified and therefore was set to '{config_file}'")

    check_infile_status(config_file, "yaml")

    if outdir is None:
        outdir = DEFAULT_OUTDIR
        print_yellow(f"--outdir was not specified and therefore was set to '{outdir}'")

    if not os.path.exists(outdir):
        pathlib.Path(outdir).mkdir(parents=True, exist_ok=True)
        print_yellow(f"Created output directory '{outdir}'")

    if logfile is None:
        logfile = os.path.join(
            outdir,
            os.path.splitext(os.path.basename(__file__))[0] + '.log'
        )
        print_yellow(f"--logfile was not specified and therefore was set to '{logfile}'")

    logging.basicConfig(
        filename=logfile,
        format=DEFAULT_LOGGING_FORMAT,
        level=DEFAULT_LOGGING_LEVEL,
    )

    if verbose:
        logging.info(f"Will load contents of config file '{config_file}'")
        console.print(f"Will load contents of config file '{config_file}'")
    config = yaml.safe_load(pathlib.Path(config_file).read_text())

    find_samplesheet(config_file, config)

    if verbose:
        console.print(f"The log file is '{logfile}'")
        print_green(f"Execution of '{os.path.abspath(__file__)}' completed")


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
import sys
import click
import pathlib
import logging
import pathlib
import yaml

from rich.console import Console
from rich.progress import Progress
from datetime import datetime
from typing import Any, Dict

from .console_helper import print_red, print_yellow, print_green
from .file_utils import check_indir_status, check_infile_status, calculate_md5, get_file_size, get_file_creation_date, get_file_list_from_directory
from .helper import get_analyis_type, get_batch_id

console = Console()

DEFAULT_PROJECT = "bg-helper-utils"


# If set to True, will profile each of the files nest in the
# batch analysis directory. This means the following attributes
# will be derived and printed to the report file:
# - file size
# - md5sum
# - date created
DEFAULT_PROFILE_DIR_FILES = False

DEFAULT_TIMESTAMP = str(datetime.today().strftime("%Y-%m-%d-%H%M%S"))

DEFAULT_OUTDIR = os.path.join(
    "/tmp/",
    os.getenv("USER"),
    DEFAULT_PROJECT,
    os.path.basename(__file__),
    DEFAULT_TIMESTAMP,
)

DEFAULT_CONFIG_FILE = os.path.join(
    os.getcwd(),
    'conf',
    'config.yaml'
)

DEFAULT_LOGGING_FORMAT = "%(levelname)s : %(asctime)s : %(pathname)s : %(lineno)d : %(message)s"

DEFAULT_LOGGING_LEVEL = logging.INFO

DEFAULT_VERBOSE = False


error_console = Console(stderr=True, style="bold red")

console = Console()


def find_batch_analysis_dir(
        config_file: str,
        config: Dict[str, Any],
        logfile: str,
        outdir: str,
        outfile: str,
        profile: bool = DEFAULT_PROFILE_DIR_FILES) -> None:
    """Find the samplesheet.

    Args:
        config_file (str): the configuration file path
        config (Dict[str, Any]): The configuration
    """
    if "analysis_base_dir" not in config:
        raise Exception(f"Could not find 'analysis_base_dir' in config file '{config_file}'")

    analysis_base_dir= config["analysis_base_dir"]
    check_indir_status(analysis_base_dir)

    analysis_type = get_analyis_type()
    batch_id = get_batch_id()

    if "batch_analysis" not in config:
        raise Exception(f"Could not find 'batch_analysis' in config file '{config_file}'")

    if "analysis_file_type_mapping" not in config["batch_analysis"]:
        raise Exception(f"Could not find 'analysis_file_type_mapping' in 'batch_analysis' section in config file '{config_file}'")

    if analysis_type not in config["batch_analysis"]["analysis_file_type_mapping"]:
        raise Exception(f"Could not find analysis type '{analysis_type}' in 'analysis_file_type_mapping' in 'batch_analysis' section in config file '{config_file}'")

    analysis_file_type = config["batch_analysis"]["analysis_file_type_mapping"][analysis_type]

    analysis_dir = os.path.join(analysis_base_dir, analysis_file_type, batch_id)

    check_indir_status(analysis_dir)

    if profile:
        console.print(f"[bold green]Profiling batch analysis directory[/] '{analysis_dir}'")
        profile_dir_files(analysis_dir, outfile, logfile, config_file)
    else:
        console.print(f"[bold green]Found batch analysis directory[/] '{analysis_dir}'")


def profile_dir_files(analysis_dir: str, outfile: str, logfile: str, config_file: str)  -> None:
    file_list = get_file_list_from_directory(analysis_dir)
    if len(file_list) == 0:
        print_red(f"Could not find any files in directory '{analysis_dir}'")
        sys.exit(0)

    lookup = {}

    count = len(file_list)

    with Progress() as progress:
        task = progress.add_task(f"[cyan]Profiling {count} files", total=count)

        for f in file_list:
            md5sum = calculate_md5(f)
            filesize = get_file_size(f)
            date_created = get_file_creation_date(f)
            lookup[f] = {
                "md5sum": md5sum,
                "filesize": filesize,
                "date_created": date_created,
            }
            progress.update(task, advance=1)


    generate_report(lookup, analysis_dir, outfile, logfile, config_file, count)


def generate_report(lookup: Dict[str, Dict[str, str]], analysis_dir: str, outfile: str, logfile: str, config_file: str, count: int) -> None:

    with open(outfile, 'w') as of:
        of.write(f"## method-created: {os.path.abspath(__file__)}\n")
        of.write(f"## date-created: {str(datetime.today().strftime('%Y-%m-%d-%H%M%S'))}\n")
        of.write(f"## created-by: {os.environ.get('USER')}\n")
        of.write(f"## batch-analysis-dir: {analysis_dir}\n")
        of.write(f"## config-file: {config_file}\n")
        of.write(f"## logfile: {logfile}\n")

        with Progress() as progress:
            task = progress.add_task(f"[cyan]Generating report for {count} files", total=count)

            for f in lookup:
                md5sum = lookup[f]["md5sum"]
                filesize = lookup[f]["filesize"]
                date_created = lookup[f]["date_created"]
                line = f"{f}\nmd5sum: {md5sum}\nbytesize: {filesize}\ndate created: {date_created}"

                of.write(f"{line}\n\n")

                progress.update(task, advance=1)

    logging.info(f"Wrote report file '{outfile}'")
    print(f"Wrote report file '{outfile}'")


def validate_profile(ctx, param, value):
    if value is None:
        click.secho("--profile was not specified and therefore was set to 'True'", fg='yellow')
        return DEFAULT_PROFILE_DIR_FILES
    return value

def validate_verbose(ctx, param, value):
    if value is None:
        click.secho("--verbose was not specified and therefore was set to 'True'", fg='yellow')
        return DEFAULT_VERBOSE
    return value


@click.command()
@click.option('--config_file', type=click.Path(exists=True), help=f"Optional: The configuration file for this project - default is '{DEFAULT_CONFIG_FILE}'")
@click.option('--logfile', help="Optional: The log file")
@click.option('--outdir', help=f"Optional: The default is the current working directory - default is '{DEFAULT_OUTDIR}'")
@click.option('--outfile', help="Optional: The output report file containing profile metadata")
@click.option('--profile', is_flag=True, help=f"Optional: If set to True, will profile all files in the batch analysis directory - default is '{DEFAULT_PROFILE_DIR_FILES}'.", callback=validate_profile)
@click.option('--verbose', is_flag=True, help=f"Optional: Will print more info to STDOUT - default is '{DEFAULT_VERBOSE}'.", callback=validate_verbose)
def main(config_file: str, logfile: str, outdir: str, outfile: str, profile: bool, verbose: bool):
    """Find the samplesheet."""
    error_ctr = 0

    if error_ctr > 0:
        click.echo(click.get_current_context().get_help())
        sys.exit(1)

    if config_file is None:
        config_file = DEFAULT_CONFIG_FILE
        print_yellow(f"--config_file was not specified and therefore was set to '{config_file}'")

    if outdir is None:
        outdir = DEFAULT_OUTDIR
        print_yellow(f"--outdir was not specified and therefore was set to '{outdir}'")

    if not os.path.exists(outdir):
        pathlib.Path(outdir).mkdir(parents=True, exist_ok=True)
        print_yellow(f"Created output directory '{outdir}'")

    if logfile is None:
        logfile = os.path.join(
            outdir,
            os.path.splitext(os.path.basename(__file__))[0] + '.log'
        )
        print_yellow(f"--logfile was not specified and therefore was set to '{logfile}'")

    if outfile is None:
        outfile = os.path.join(
            outdir,
            os.path.splitext(os.path.basename(__file__))[0] + '.report.txt'
        )
        print_yellow(f"--outfile was not specified and therefore was set to '{outfile}'")

    logging.basicConfig(
        filename=logfile,
        format=DEFAULT_LOGGING_FORMAT,
        level=DEFAULT_LOGGING_LEVEL,
    )

    check_infile_status(config_file, "yaml")

    if verbose:
        logging.info(f"Will load contents of config file '{config_file}'")
        console.log(f"Will load contents of config file '{config_file}'")
    config = yaml.safe_load(pathlib.Path(config_file).read_text())


    find_batch_analysis_dir(
        config_file,
        config,
        logfile,
        outdir,
        outfile,
        profile
    )

    if verbose:
        console.print(f"The log file is '{logfile}'")
        print_green(f"Execution of '{os.path.abspath(__file__)}' completed")


if __name__ == "__main__":
    main()



#!/usr/bin/env python

"""Tests for `bg_helper_utils` package."""


import unittest
from click.testing import CliRunner

from bg_helper_utils import bg_helper_utils
from bg_helper_utils import cli


class TestBg_helper_utils(unittest.TestCase):
    """Tests for `bg_helper_utils` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""

    def test_command_line_interface(self):
        """Test the CLI."""
        runner = CliRunner()
        result = runner.invoke(cli.main)
        assert result.exit_code == 0
        assert 'bg_helper_utils.cli.main' in result.output
        help_result = runner.invoke(cli.main, ['--help'])
        assert help_result.exit_code == 0
        assert '--help  Show this message and exit.' in help_result.output



from rich.console import Console

error_console = Console(stderr=True, style="bold red")

console = Console()


def print_red(msg: str = None) -> None:
    if msg is None or msg == "":
        raise Exception("msg was not defined")
    error_console.print(msg)


def print_green(msg: str = None) -> None:
    if msg is None or msg == "":
        raise Exception("msg was not defined")

    console.print(f"[bold green]{msg}[/]")

def print_yellow(msg: str = None) -> None:
    if msg is None or msg == "":
        raise Exception("msg was not defined")

    console.print(f"[bold yellow]{msg}[/]")



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=7.0',
    "Rich",
    "PyYAML",
]

test_requirements = [ ]

setup(
    author="Jaideep Sundaram",
    author_email='jai.python3@gmail.com',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Collection of Python convenience scripts for BG tasks.",
    entry_points={
        'console_scripts': [
            'find-samplesheet=bg_helper_utils.find_samplesheet:main',
            'find-batch-analysis-dir=bg_helper_utils.find_batch_analysis_dir:main',
        ],
    },
    install_requires=requirements,
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='bg_helper_utils',
    name='bg_helper_utils',
    packages=find_packages(include=['bg_helper_utils', 'bg_helper_utils.*']),
    package_data={"bg_helper_utils": ["conf/config.yaml"]},
    scripts=["scripts/generate_executables_and_aliases.py"],
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/jai-python3/bg-helper-utils',
    version='0.4.0',
    zip_safe=False,
)
